/**************************************************************

   Program Title:  Wasp AVR Monitor
   
   Program Name:  Nokia_LCD.c	Version: 0.85
   
   Author:  SS	  			    Date:  August 10, 2005
   
   Compiled with ImageCraft ICCAVR Standard V7.13A.
   
   This file contains routines that implement an TWI Master and Slave
   interrupt driven controller.
   
   Copyright 2004-2009, SOC Robotics, Inc.  All rights reserved.
  
****************************************************************/
/*
 * Copyright 2004-2009, SOC Robotics, Inc.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the copyright holders nor the names of
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 * 4. Redistribution is only allowed in combination with SOC Machines, 
 *    Inc. hardware products.
 *
 * THIS SOFTWARE IS PROVIDED BY SOC ROBOTICS, INC. AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL OC MACHINES, 
 * INC. OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * For additional information see http://www.soc-robotics.com
 */

/*
 * $Log: Nokia_LCD.c,v $
 * Revision 0.86  2006/02/07 16:40:20  SS
 *    2-wire interface, 8MHz clock, AVR Flash writer, XON/XOFF, 38,700baud
 * Revision 0.52  2005/06/04 18:36:42  SS
 * Preview release
 *
 */
#include <iom644v.h>
#include <macros.h>
#include <string.h>
#include <stdlib.h>
#include <math.h>
#include <stdio.h>
#include "Wasp_Uart.h"
#include "Wasp_Defines.h"
#include "Wasp_Extern.h"

// Epson S1D15G10 Command Set
#define DISON       0xaf   
#define DISOFF      0xae   
#define DISNOR      0xa6  
#define DISINV      0xa7  
#define COMSCN      0xbb   
#define DISCTL      0xca   
#define SLPIN       0x95   
#define SLPOUT      0x94   
#define PASET       0x75   
#define CASET       0x15   
#define DATCTL      0xbc   
#define RGBSET8     0xce   
#define RAMWR       0x5c   
#define RAMRD       0x5d   
#define PTLIN       0xa8   
#define PTLOUT      0xa9   
#define RMWIN       0xe0   
#define RMWOUT      0xee   
#define ASCSET      0xaa   
#define SCSTART     0xab   
#define OSCON       0xd1   
#define OSCOFF      0xd2   
#define PWRCTR      0x20   
#define VOLCTR      0x81   
#define VOLUP       0xd6   
#define VOLDOWN     0xd7   
#define TMPGRD      0x82   
#define EPCTIN      0xcd   
#define EPCOUT      0xcc   
#define EPMWR       0xfc   
#define EPMRD       0xfd   
#define EPSRRD1     0x7c   
#define EPSRRD2     0x7d   
#define NOPP        0x25    


// LCD Chip Select
#define LCD_CS    0x00200000;
#define LCD_RESET    0x00400000;
#define LCD_SCK     0x00020000;
#define LCD_DI     0x00080000;

// general purpose
void delay_ms(int);

// spi functions use whatever method you want
//void spi_command(int);
//void spi_data(int);
//void spi_init(void);

void SPI_Write_Bit(unsigned char cbit)
{
 	 ClrBit(PORTB,PINB7);
	 // Set bit
	 if(cbit) SetBit(PORTB,PINB5);
	 else ClrBit(PORTB,PINB5);
 	 SetBit(PORTB,PINB7);	 
}

void SPI_Transmit(unsigned char cData)
{
 	 unsigned char dmask;
 	 int i;
	 
	 dmask = 0x80;
	 for(i=0; i<8; i++)  {
	    if((cData&dmask)) SPI_Write_Bit(1);
		else SPI_Write_Bit(0);
		dmask = (dmask>>1);
		}
}

// Nokia LCD uses 9bit serial data - first bit high - data
void spi_command(unsigned char cData)
{
 	 ClrBit(PORTB,PINB3);
	 SPI_Write_Bit(0);
 	 SPI_Transmit(cData);
	 SetBit(PORTB,PINB3);
}

void spi_data(unsigned char cData)
{
 	 ClrBit(PORTB,PINB3);
	 SPI_Write_Bit(1);
 	 SPI_Transmit(cData);
	 SetBit(PORTB,PINB3);
}

void  SPI_MasterTransmit_CS(unsigned char cData)
{
 	  ClrBit(PORTB,PINB3);
	  shortdelay(2);
 	  SPI_MasterTransmit_CS(cData);
	  shortdelay(3000);
	  SetBit(PORTB,PINB3);
}

// this can be the basis for more complex graphics
void LCD_put_pixel(unsigned char color, unsigned char x, unsigned char y) 
{
    x += 2;              // for some reason starts at 2
    spi_command(0x75);   // page start/end ram
    spi_data(x);            
    spi_data(132);          
    spi_command(0x15);   // column start/end ram
    spi_data(y);         // for some reason starts at 2
    spi_data(131); 
    spi_command(0x5C);    // write data
    spi_data(color); 
}

const unsigned char Char_Array[]={
	   0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,  // ' '
	   0x08,0x08,0x08,0x08,0x08,0x08,0x00,0x00,0x08,  // '!'
	   0x00,0x22,0x44,0x00,0x00,0x00,0x00,0x00,0x00,  // '"'
	   0x00,0x12,0x12,0xFE,0x24,0x48,0xFE,0x48,0x00,  // '#'
	   0x08,0x3C,0x62,0x40,0x80,0x40,0x20,0x3C,0x08,  // '$'
	   0x20,0x20,0x02,0x06,0x3C,0x60,0x10,0x10,0x00,  // '%'
	   0x18,0x3C,0x40,0x20,0x3C,0x48,0x84,0x42,0x3C,  // '&'
	   0x10,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,  // '''
	   0x04,0x08,0x10,0x20,0x40,0x20,0x10,0x80,0x40,  // '('
       0x40,0x20,0x10,0x10,0x80,0x40,0x80,0x10,0x20,  // ')'
	   0x00,0x10,0x10,0x3C,0x24,0x42,0x42,0x42,0x00,  // '*'
	   0x00,0x10,0x10,0x10,0x7E,0x10,0x10,0x10,0x00,  // '+'
	   0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x20,0x40,  // ','
	   0x00,0x00,0x00,0x00,0x7E,0x00,0x00,0x00,0x00,  // '-'
	   0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x00,  // '.'
	   0x02,0x04,0x04,0x08,0x08,0x10,0x20,0x40,0x80,  // '/'
	   0x7C,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x7C,  // '0'
	   0x04,0x0C,0x04,0x04,0x04,0x04,0x04,0x04,0x04,  // '1'
	   0xFE,0x02,0x02,0x04,0x3C,0x40,0x80,0x80,0xFE,  // '2'
	   0xFE,0x02,0x02,0x02,0xFE,0x02,0x02,0x02,0xFE,  // '3'
	   0x80,0x88,0x88,0x88,0xFE,0x08,0x08,0x08,0x08,  // '4'
	   0xFE,0x80,0x80,0x80,0xFE,0x02,0x02,0x02,0xFE,  // '5'
	   0xC0,0x80,0x80,0x80,0xFE,0x82,0x82,0x82,0xFE,  // '6'
	   0xFE,0x82,0x02,0x04,0x04,0x04,0x04,0x04,0x04,  // '7'
	   0xFE,0x82,0x82,0x82,0xFE,0x82,0x82,0x82,0xFE,  // '8'
       0xFE,0x82,0x82,0x82,0xFE,0x02,0x02,0x02,0x02,  // '9'
	   0x00,0x00,0x00,0x10,0x00,0x00,0x10,0x00,0x00,  // ':'
	   0x00,0x00,0x00,0x10,0x00,0x00,0x10,0x20,0x00,  // ';'
	   0x00,0x02,0x04,0x08,0x10,0x08,0x04,0x02,0x00,  // '<'
	   0x00,0x00,0x00,0xFE,0x00,0x00,0xFE,0x00,0x00,  // '='
	   0x00,0x80,0x40,0x20,0x10,0x80,0x10,0x20,0x40,  // '>'
	   0x08,0x14,0x24,0x42,0x04,0x08,0x08,0x00,0x08,  // '?'
	   0x3C,0x44,0x82,0x82,0x94,0x9c,0x80,0x82,0x3c,  // '@'
	   0x08,0x18,0x14,0x24,0x24,0x7C,0x44,0x82,0x82,  // 'A'
	   0xFC,0x82,0x82,0x82,0xFE,0x82,0x82,0x82,0xFC,  // 'B'
       0x7C,0x82,0x80,0x80,0x80,0x80,0x80,0x82,0x7C,  // 'C'
	   0xFC,0x82,0x82,0x82,0x82,0x82,0x82,0x82,0xFC,  // 'D'
	   0xFC,0x80,0x80,0x80,0xF8,0x80,0x80,0x80,0xFC,  // 'E'
	   0xFC,0x80,0x80,0x80,0xF8,0x80,0x80,0x80,0x80,  // 'F'
	   0x7C,0x84,0x84,0x80,0x9C,0x8A,0x88,0x88,0x70,  // 'G'
	   0x82,0x82,0x82,0x82,0xFE,0x82,0x82,0x82,0x82,  // 'H'
	   0x1C,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x1C,  // 'I'
	   0x7E,0x08,0x08,0x08,0x08,0x08,0x08,0x88,0x70,  // 'J'
	   0x84,0x88,0x90,0xA0,0xC0,0xA0,0x90,0x88,0x84,  // 'K'
	   0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0xFE,  // 'L'
       0x82,0xC6,0xAA,0x9A,0x8A,0x82,0x82,0x82,0x82,  // 'M'
	   0x82,0xC2,0x92,0x92,0x92,0x8A,0x8A,0x86,0x82,  // 'N'
	   0x3C,0x44,0x82,0x82,0x82,0x82,0x82,0x44,0x3C,  // 'O'
	   0xFC,0x82,0x82,0x82,0xFC,0x80,0x80,0x80,0x80,  // 'P'
	   0x3C,0x44,0x82,0x82,0x82,0x82,0x8A,0x44,0x3A,  // 'Q'
	   0xFC,0x82,0x82,0x82,0xFC,0x90,0x88,0x84,0x82,  // 'R'
	   0x38,0x44,0x82,0x80,0x7C,0x02,0x82,0x44,0x38,  // 'S'
	   0xFE,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,  // 'T'
	   0x82,0x82,0x82,0x82,0x82,0x82,0x82,0x86,0x7A,  // 'U'
	   0x82,0x82,0x44,0x44,0x28,0x28,0x28,0x18,0x10,  // 'V'
       0x82,0x82,0x82,0x82,0x90,0xAA,0xAA,0xC7,0x82,  // 'W'
	   0x82,0x44,0x28,0x18,0x10,0x18,0x28,0x44,0x82,  // 'X'
	   0x82,0x44,0x28,0x10,0x08,0x08,0x08,0x08,0x08,  // 'Y'
	   0xFE,0x04,0x04,0x08,0x08,0x10,0x20,0x40,0xFE,  // 'Z'
	   0xFE,0x80,0x80,0x80,0xFE,0x02,0x02,0x02,0xFE,  // '['
	   0x80,0x40,0x20,0x10,0x10,0x08,0x04,0x02,0x02,  // '\'
	   0xFE,0x82,0x02,0x04,0x04,0x04,0x04,0x04,0x04,  // ']'
	   0xFE,0x82,0x82,0x82,0xFE,0x82,0x82,0x82,0xFE,  // '^'
       0xFE,0x82,0x82,0x82,0xFE,0x02,0x02,0x02,0x02,  // '_'
	   0xC0,0x80,0x80,0x80,0xFE,0x82,0x82,0x82,0xFE,  // '`'
	   0x00,0x00,0x00,0x7C,0x82,0x82,0x82,0x86,0x7A,  // 'a'
	   0x80,0x80,0x80,0x80,0xFC,0x82,0x82,0x82,0xFC,  // 'b'
       0x00,0x00,0x00,0x00,0x7C,0x82,0x80,0x82,0x7C,  // 'c'
	   0x02,0x02,0x02,0x02,0x7E,0x82,0x82,0x82,0x7C,  // 'd'
	   0x00,0x00,0x00,0x7C,0x82,0xFE,0x80,0x80,0x7C,  // 'e'
	   0x0C,0x12,0x12,0x10,0x3C,0x10,0x10,0x10,0x10,  // 'f'
	   0x00,0x00,0x7C,0x82,0x82,0x7E,0x02,0x02,0x3C,  // 'g'
	   0x80,0x80,0x80,0x80,0xFC,0x82,0x82,0x82,0x82,  // 'h'
	   0x00,0x00,0x00,0x08,0x00,0x08,0x08,0x08,0x08,  // 'i'
	   0x00,0x00,0x08,0x00,0x08,0x08,0x08,0x88,0x70,  // 'j'
	   0x80,0x80,0x90,0xA0,0xC0,0x90,0x88,0x84,0x82,  // 'k'
	   0x18,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x3C,  // 'l'
       0x00,0x00,0x00,0x00,0xF6,0x9A,0x9A,0x9A,0x9A,  // 'm'
	   0x00,0x00,0x00,0x80,0xFC,0x82,0x82,0x82,0x82,  // 'n'
	   0x00,0x00,0x00,0x7C,0x82,0x82,0x82,0x82,0x7C,  // 'o'
	   0x00,0x00,0x7C,0x82,0x82,0x82,0xFC,0x80,0x80,  // 'p'
	   0x00,0x00,0x7C,0x82,0x82,0x82,0x7E,0x02,0x02,  // 'q'
	   0x00,0x00,0x00,0x10,0x1C,0x10,0x10,0x10,0x10,  // 'r'
	   0x00,0x00,0x7C,0x82,0x80,0x7C,0x02,0x82,0x7C,  // 's'
	   0x08,0x08,0x08,0x3C,0x08,0x08,0x08,0x08,0x04,  // 't'
	   0x00,0x00,0x00,0x82,0x82,0x82,0x82,0x86,0x7A,  // 'u'
	   0x00,0x00,0x00,0x82,0x44,0x44,0x28,0x28,0x10,  // 'v'
       0x00,0x00,0x00,0x82,0x82,0x9A,0x9A,0x9A,0x66,  // 'w'
	   0x00,0x00,0x82,0x44,0x28,0x10,0x28,0x44,0x82,  // 'x'
	   0x00,0x00,0x82,0x82,0x82,0x96,0x7A,0x02,0x1E,  // 'y'
	   0x00,0x00,0xFE,0x04,0x08,0x10,0x20,0x40,0xFE,  // 'z'
       0xFE,0x82,0x82,0x82,0xFE,0x02,0x02,0x02,0x02,  // '{'
	   0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,0x08,  // '|'
	   0x20,0x10,0x10,0x08,0x04,0x08,0x10,0x10,0x20,  // '}'
	   0x00,0x00,0x44,0x91,0x89,0x86,0x06,0x00,0x00}; // '~'

void Write_Char_LCD(unsigned char x,unsigned char y,
                    unsigned outchar,unsigned char color)
{
 	 unsigned char mask,outbyte;
 	 int i,j;

//	while((inchar=*(signon1+i++))!=0x00)  putchar(inchar);
	 
	 for(i=0; i<9; i++) {
	     mask = 0x80;
		 outbyte = *(Char_Array+i+(outchar-' ')*9);
	     for(j=0; j<8; j++) {
		     if((mask&outbyte)) LCD_put_pixel(color,x-i,y-j);
			 else LCD_put_pixel(0xFF,x-i,y-j);
			 mask = (mask>>1);
		     }
		}
}

void LCD_Puts(unsigned char x,unsigned char y,char *instrg,unsigned char color)
{
    int i,instrglen;
	
	instrglen = strlen(instrg);
	i = 0;
	while(i<instrglen)  Write_Char_LCD(y,129-(x+i*8),instrg[i++],color);
}

void  Cycle_LCD(void)
{
 	char outstrg[20];
 	int i;
	
//    for(i=0; i<105; i++) {   // this loop adjusts the contrast, change the number of iterations to get
    for(i=0; i<108; i++) {   // this loop adjusts the contrast, change the number of iterations to get
//    for(i=0; i<50; i++) {   // this loop adjusts the contrast, change the number of iterations to get
        spi_command(VOLUP);   // desired contrast.  This might be different for individual LCDs             
		sprintf(outstrg,"%d",i,0);
        LCD_Puts(4,30,"volup=",0);
        LCD_Puts(70,30,outstrg,0);
		Delaymsec(2);
        }
    for(i=0; i<108; i++) {   // this loop adjusts the contrast, change the number of iterations to get
        spi_command(VOLDOWN);   // desired contrast.  This might be different for individual LCDs             
		sprintf(outstrg,"%d",i);
        LCD_Puts(4,30,"voldown=",0);
        LCD_Puts(70,30,outstrg,0);
		Delaymsec(2);
        }
}

void Draw_Boxes_Once()
{
 	unsigned char inchar;
	
	Draw_Background(0xff);
	printf("Draw boxes\n");
	Draw_Color_Bars(28);
	Draw_Boxes(38);
	LongDelay(40);
	Draw_Background(0xff);
}

void Draw_Boxes_Continuously()
{
 	unsigned char inchar;
	
	printf("3\nDraw boxes continuously");
	printf(" - press any key to exit\n");
	Draw_Background(0xff);
	while(!(inchar=getcharnw())) {
		printf("Draw boxes\n");
		Draw_Color_Bars(28);
		Draw_Boxes(38);
		LongDelay(40);
		Draw_Background(0xff);
		}
}

void Draw_Menu_Command()
{
	printf("m\nEnter Menu command:");
	Draw_Background(0xff);
	cursorlocation = 0;
	//Draw_Menu();
	LCD_Puts(9,113,"LED Off/On - Right SW",0x03);
	LCD_Puts(9,99,"Boxes - Sw right",0x03);
	LCD_Puts(9,85,"Alphabet - Up",0x03);
	LCD_Puts(9,72,"Force - Down",0x03);
	LCD_Puts(9,59,"Gravity - Left",0x03);
	LCD_Puts(9,46,"SOC Logo - Down",0x03);
	LCD_Puts(9,33,"Erase Scren - Center",0x03);
							
	LCD_Puts(1,113,">",0x03);
	printf("\n-");
}

void Nokia_LED(char state)
{
 	 if(state==ON)  SetBit(PORTD,PIND2);
	 else ClrBit(PORTD,PIND2);
}

void Draw_Box(unsigned char xlow,unsigned char ylow,
              unsigned char xhigh,unsigned char yhigh,unsigned char color)
{
     int i;
	 
 	 for(i=xlow; i<xhigh; i++) LCD_put_pixel(color,i,ylow);
 	 for(i=ylow; i<yhigh; i++) LCD_put_pixel(color,xhigh,i);
 	 for(i=xhigh; i>xlow; i--) LCD_put_pixel(color,i,yhigh);
 	 for(i=yhigh; i>ylow; i--) LCD_put_pixel(color,xlow,i); 
}

//unsigned char bmp_logo_image[69][128] = {
const unsigned char bmp_logo_image[] = {
        0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xb6,0xf7,0x9d,0x7,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf6,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf7,0xab,0x7,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xf6,0x52,0x0,0x9a,0xff,0xff,0xff,0x50,0xae,0xff,0xff,0x8,0x12,0x0,0x0,0xb5,0xff,0xff,0xff,0xff,0x0,0x0,0x53,0xff,0xff,0xff,0xff,0x7,0x9b,0x0,0x0,0x9a,0xff,0xff,0xff,0xff,0xff,0xff,0xf6,0x9a,0x0,0x9b,0x7,0x7,0x9d,0x0,0x53,0xff,0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x50,0x7,0xff,0xff,0xff,0xff,0x9b,0x0,0x0,0x9b,0xff,0xff,0xff,0xff,0xff,0x52,0x0,0x0,0xf5,0xff,0xff,0xff,0xff,0x9d,0x0,0x0,0xed,0xff,0xff,0xff,0xff,0xff,0xff,0x7,0x0,0xff,0xff,0xff,0xff,0xff,0xab,0x0,0x0,0x0,0x92,0x52,0x90,0xa,0x0,0x0,0xff,0xff,0xff,0xff,0xff,0x9d,0x40,0x52,0xf5,0xee,0x9b,0x0,0xff,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0x10,0xff,0xff,0xff,0x8,0x0,0x40,0xff,0xff,0xff,0xff,0x0,0xf7,0xff,0xff,0xff,0xff,0xff,0xff,0x52,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x0,0x9b,0xff,0xff,0xff,0xff,0xff,0xff,0xef,0x10,0x12,0xff,0xff,0xff,0xff,0xff,0xff,0x9a,0x52,0xff,0xff,0xff,0xff,0xff,0xae,0x0,0x7,0xff,0xff,0xff,0xff,0xff,0xff,0x50,0x52,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x0,0xab,0xff,0xff,0xff,0xff,0xff,0xff,0x9b,0xf5,0xff,0xff,0xff,0xff,0xff,0xff,0x7,0x50,0x0,0xff,0xff,0xff,0xff,0xff,0xff,0x9,0x0,0x7,0xff,0xff,0xff,0xff,0xff,0x9b,0x9d,0xff,0xff,0xff,0xff,0x0,0xf7,0xff,0xff,0xff,0xff,0xff,0x0,0x7,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0xa,0xff,0xff,0xff,0xf7,0x0,0x9d,0xf7,0xff,0xff,0xef,0x0,0xf7,0xff,0xff,0xff,0xff,0xff,0xff,0x9b,0xf7,0xff,0xff,0xff,0xff,0xff,0x9b,0x0,0x7,0xff,0xff,0xff,0xff,0xff,0xf6,0x52,0x0,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xab,0xff,0xff,0xff,0xff,0xff,0xf5,0x0,0xf5,0xff,0xff,0xff,0xff,0xff,0xff,0x42,0x5a,0xff,0xff,0xff,0xff,0xff,0xff,0xef,0x0,0x9d,0xff,0xff,0xff,0xff,0xff,0xff,0xab,0xae,0xff,0xff,0xff,0xff,0xff,0xff,0x0,0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,0xee,0x0,0xef,0xff,0xff,0xff,0xff,0xff,0xff,0xf5,0xff,0xff,0xff,0xff,0x9b,0xff,0xff,0xff,0xff,0xff,0xff,0x0,0x5b,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0x92,0xff,0xff,0xf6,0x10,0x12,0xff,0x52,0xff,0xff,0x7,0x0,0xf5,0xff,0xff,0xff,0xff,0xff,0xff,0x7,0x52,0xff,0xff,0xff,0xff,0xf6,0x50,0xa,0xff,0xff,0xff,0xff,0xff,0xff,0xf7,0x0,0xf7,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xae,0x0,0xb6,0xff,0xff,0xff,0xff,0xff,0xff,0x90,0x52,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x0,0xf7,0xff,0xff,0xff,0xff,0xff,0xff,0x9d,0xf5,0xff,0xff,0xff,0xff,0xff,0x50,0x0,0x8,0xa,0xff,0xff,0xff,0xff,0xff,0xff,0x7,0x0,0x8,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x0,0xab,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0x42,0xff,0xff,0xf7,0x0,0x7,0xff,0x9a,0xee,0xff,0xee,0x0,0xee,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x53,0xf5,0xef,0xff,0xf6,0xab,0x0,0xf5,0xff,0xff,0xff,0xff,0xff,0xff,0x9b,0x0,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf5,0x0,0x7,0xff,0xff,0xff,0xff,0xff,0xff,0x42,0x52,0xff,0xff,0xff,0xff,0xff,0xff,0xf6,0x0,0xad,0xff,0xff,0xff,0xff,0xff,0xff,0x9b,0xae,0xff,0xff,0xff,0xff,0x50,0x0,0xed,0xff,0x10,0xff,0xff,0xff,0xff,0xff,0xff,0x7,0x0,0xef,0xff,0xff,0xff,0xef,0xab,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xef,0xf7,0x0,0x0,0xae,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0x5a,0xf6,0xff,0x0,0x9a,0xff,0xff,0xb6,0x9b,0xff,0xf5,0x0,0x8,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x0,0xab,0x9b,0xab,0x52,0x40,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x9b,0x0,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xae,0x0,0x52,0x92,0x52,0x5a,0x52,0x92,0x53,0x10,0x52,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x0,0xf7,0xff,0xff,0xff,0xff,0xff,0xff,0x9b,0xf5,0xff,0xff,0xff,0x52,0x0,0xf7,0xff,0xff,0x0,0xff,0xff,0xff,0xff,0xff,0xff,0x9,0x0,0x52,0x52,0x92,0x52,0x50,0x5b,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x5b,0x50,0x0,0x0,0xb6,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0x53,0xff,0x9d,0x0,0xae,0xff,0xff,0xff,0xa,0xff,0xae,0x0,0xef,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x52,0xef,0xff,0xef,0x0,0xae,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x9d,0x0,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf5,0x0,0xf5,0xf6,0xff,0xef,0xff,0xf6,0xff,0x52,0x50,0xff,0xff,0xff,0xff,0xff,0xff,0xef,0x0,0xad,0xff,0xff,0xff,0xff,0xff,0xff,0xab,0xae,0xff,0xff,0x50,0x0,0xab,0xff,0xff,0xff,0x0,0xff,0xff,0xff,0xff,0xff,0xff,0xee,0x0,0x7,0xff,0xf6,0xff,0x9b,0x9a,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xab,0x0,0x0,0x52,0x7,0xf6,0xff,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0x9b,0x7,0x50,0x52,0xff,0xff,0xff,0xff,0xff,0x52,0xf5,0x0,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xb6,0x9a,0xff,0x9a,0xa,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xb5,0x0,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xb6,0x0,0xb6,0xff,0xff,0xff,0xff,0xff,0xff,0x90,0x12,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x0,0xf7,0xff,0xff,0xff,0xff,0xff,0xff,0x9d,0xf5,0xff,0x9a,0x0,0xf7,0xff,0xff,0xff,0xff,0x0,0xff,0xff,0xff,0xff,0xff,0xff,0x7,0x0,0x8,0xff,0xff,0xff,0xff,0x7,0xff,0xff,0xff,0xff,0xff,0xff,0xf5,0x0,0x92,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0x9d,0x9b,0x0,0x7,0xff,0xff,0xff,0xff,0xff,0x9a,0x9d,0x0,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x53,0xff,0x0,0x9b,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf6,0x50,0x52,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xae,0x7,0xff,0xff,0xff,0xff,0xff,0xf5,0x0,0xf5,0xff,0xff,0xff,0xff,0xff,0xff,0x42,0x52,0xff,0xff,0xff,0xff,0xff,0xff,0xef,0x0,0xad,0xff,0xff,0xff,0xff,0xff,0xff,0x9b,0x7,0x9b,0x0,0xab,0xff,0xff,0xff,0xff,0xff,0x0,0xff,0xff,0xff,0xff,0xff,0xff,0x7,0x0,0xef,0xff,0xff,0xff,0xff,0xff,0x7,0xff,0xff,0xff,0xff,0xff,0x5d,0x0,0xef,0xff,0xff,0xff,0xff,0xff,0xef,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0x9b,0x0,0x50,0xff,0xff,0xff,0xff,0xff,0xff,0x7,0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf7,0xa,0x0,0x7,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf6,0x0,0x9b,0xff,0xff,0xff,0xff,0xff,0xf6,0x50,0xae,0xff,0xff,0xff,0xff,0xff,0xae,0x0,0x7,0xff,0xff,0xff,0xff,0xff,0xff,0x50,0x52,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x0,0xab,0xff,0xff,0xff,0xff,0xff,0xff,0xad,0x9a,0x0,0x9b,0xff,0xff,0xff,0xff,0xff,0xff,0x0,0xff,0xff,0xff,0xff,0xff,0xff,0x7,0x0,0xff,0xff,0xff,0xff,0xff,0xef,0x9a,0xff,0xff,0xff,0xff,0xff,0xf5,0x0,0xff,0xff,0xff,0xff,0xff,0x52,0x8,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0x42,0x0,0xef,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x9d,0x0,0x9d,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf6,0x0,0x52,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x50,0x9b,0xf7,0xae,0xf5,0xae,0x52,0x52,0x8,0xff,0xff,0xff,0xff,0xf6,0x52,0x0,0xab,0xf6,0xff,0xff,0xff,0xf6,0xf5,0xa,0x50,0xae,0xff,0xff,0xff,0xff,0xff,0x9d,0x0,0x53,0x8,0xff,0xff,0xff,0xff,0x7,0x52,0xa,0x9b,0xff,0xff,0xff,0xff,0xff,0xff,0x9d,0x0,0xf7,0xff,0xff,0xff,0xff,0xff,0x9d,0x0,0x9d,0xab,0x9d,0xf7,0x9d,0x0,0x9d,0xff,0xff,0xff,0xff,0xff,0xff,0x9a,0x9d,0x7,0xae,0xf5,0x53,0x52,0x7,0xff,0xff,0xff,0xff,
//		};
//const unsigned char bmp_logo_image2[] = {
        0xff,0xff,0xff,0xff,0xff,0x7,0x7,0x7,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x7,0x7,0xf6,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf7,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x8,0x9b,0xf7,0xf7,0xab,0x7,0xff,0xff,0xff,0xff,0xff,0xff,0x8,0x7,0xff,0xae,0xff,0xff,0xff,0xff,0xff,0x7,0x9,0x7,0xf5,0xff,0xff,0xff,0xff,0xf6,0x7,0x7,0x7,0xb6,0xff,0xff,0xff,0xff,0x7,0xb6,0x8,0xff,0xff,0xff,0xff,0xff,0xff,0xef,0xf5,0x7,0xf5,0xef,0xff,0xff,0xff,0x7,0xf5,0x7,0xf5,0xae,0xf5,0xae,0x7,0x7,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x7,0xf7,0xf7,0x9b,0xf5,0xff,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf6,0xff,0xff,0xff,0xf6,0xff,0xf6,0xff,0xf6,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf6,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf6,0xff,0xff,0xff,0xff,0xff,0xef,0x8,0xef,0x8,0xef,0x8,0xef,0x8,0xef,0x8,0xef,0x8,0xef,0xff,0xff,0xff,0xff,0xff,0xf6,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf6,0xff,0xf6,0x8,0xb6,0x7,0x7,0x7,0xb6,0x7,0xb6,0x7,0xb6,0x7,0xb6,0x7,0xb6,0x7,0xb6,0x7,0xb6,0x7,0x7,0x8,0xb6,0xff,0xf6,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xb6,0xf5,0xee,0xf5,0xae,0xf5,0xee,0xed,0xf7,0xf7,0xf7,0xf7,0xf7,0xf7,0xf7,0xf7,0xae,0xf5,0xee,0xf5,0xae,0xf5,0xee,0xf5,0xb6,0x8,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf6,0xff,0x7,0x7,0xb6,0x7,0xf7,0xed,0xf7,0xf7,0xf7,0xed,0xf7,0xb5,0xf7,0xed,0xf7,0xb5,0xf7,0xed,0xf7,0xf7,0xf7,0xed,0xf7,0xf5,0xb6,0x7,0xb6,0xff,0xf6,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x8,0x7,0xf5,0xee,0xf5,0xee,0xf5,0xf7,0xf7,0xf7,0xf7,0xf7,0xf7,0xae,0xf7,0xf7,0xf7,0xf7,0xf7,0xf7,0xf5,0xee,0xf5,0xae,0xf5,0x7,0x7,0xf6,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf6,0xff,0xb6,0x8,0x7,0x7,0xb6,0x7,0xb6,0x7,0xb6,0x7,0xb6,0x7,0xb6,0x7,0xb6,0x7,0xb6,0x7,0xb6,0xf5,0x7,0x8,0xb6,0xff,0xf6,0xff,0xf6,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf6,0x8,0xef,0x8,0xef,0x8,0xef,0x8,0xef,0x8,0xef,0x8,0xef,0x8,0xef,0x8,0xef,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xae,0xf7,0x92,0x52,0x52,0x52,0x52,0xeb,0xae,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf6,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xae,0xf5,0xf7,0xf5,0xf7,0xf5,0x7,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf6,0x7,0x9b,0x0,0x0,0x0,0x0,0x40,0xa,0x0,0xa,0x40,0xa,0x0,0x0,0x10,0x7,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xef,0xf5,0x9b,0x42,0x0,0x0,0x0,0x0,0x0,0x0,0x53,0xb6,0xef,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xef,0x9b,0x0,0x0,0x0,0x0,0x0,0x0,0xa,0x0,0x0,0x0,0x0,0x0,0x0,0xab,0xee,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xf7,0x7,0x9d,0x52,0x0,0x0,0x0,0x9a,0xad,0x9,0xff,0xff,0xff,0xff,0xff,0xff,0xad,0x9a,0x0,0x0,0x52,0xf7,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf7,0x52,0x0,0x0,0x12,0x12,0x13,0x12,0x12,0x12,0xa,0x10,0x0,0x0,0x5b,0x7,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf6,0xed,0x12,0x0,0x0,0x0,0x52,0x9b,0xae,0x7,0xf6,0xff,0xff,0xff,0xb6,0xed,0x9b,0x52,0x0,0x0,0x0,0xab,0xb6,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0x50,0xa,0x0,0x0,0x0,0x52,0xf5,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x7,0xa,0x0,0x0,0x9a,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xab,0xa,0x0,0x1,0x12,0x1,0x1,0x1,0x1,0x1,0x12,0x1,0x12,0xa,0x12,0xa,0x0,0x0,0x9a,0xf6,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf7,0x50,0x0,0x0,0x0,0x50,0xae,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf6,0xf7,0xa,0x0,0x0,0x0,0x52,0xf7,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0x12,0x0,0x0,0x0,0x9b,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x12,0x0,0x0,0x9a,0xf6,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf6,0x5a,0xa,0x13,0x1,0x1,0x1,0x1,0x1,0x1,0x1,0x1,0x1,0x1,0x1,0x13,0x1,0x12,0x12,0x12,0x0,0x0,0xae,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x52,0x0,0x0,0x0,0x0,0xf7,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xad,0x0,0x0,0x0,0x12,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0x52,0x0,0x0,0x9d,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x7,0xa,0x0,0x0,0x9b,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xef,0x52,0xa,0x13,0x1,0x1,0x1,0x1,0x1,0x1,0x1,0x1,0x1,0x1,0x1,0x1,0x1,0x1,0x1,0x12,0x1,0x12,0xa,0x0,0x9d,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x7,0xa,0x0,0x0,0x0,0x0,0xed,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,0xf7,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0x12,0x0,0x53,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x9a,0x0,0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xef,0x52,0x1,0x1,0x1,0x1,0x1,0x1,0x1,0x1,0x1,0x1,0x1,0x1,0x1,0x1,0x1,0x1,0x1,0x1,0x1,0x13,0x13,0x12,0xa,0x0,0xad,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x12,0x0,0x0,0x0,0x0,0xf5,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xae,0x0,0x0,0x9b,0xff,0xff,0xff,0xff,
		0xff,0xff,0xff,0xff,0xff,0x9a,0x0,0x7,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xee,0x0,0x0,0x0,0x93,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xef,0x52,0x1,0x1,0x1,0x1,0x1,0x1,0x1,0x1,0x1,0x15,0x1,0x15,0x1,0x1,0x1,0x1,0x1,0x1,0x1,0x1,0x1,0x1,0x1,0x12,0xa,0x0,0xae,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x52,0x0,0x0,0x0,0x0,0xf7,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x9b,0x0,0x0,0x7,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0x52,0x52,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,0x50,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xab,0x1,0x1,0x1,0x1,0x1,0x1,0x1,0x15,0x15,0x15,0xe,0x15,0x1,0x15,0xe,0x15,0x1,0x1,0x1,0x1,0x1,0x1,0x1,0x1,0x1,0x12,0xa,0x0,0x7,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x52,0x0,0x0,0x0,0x0,0x52,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x0,0x9a,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0x9b,0x9d,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,0xa,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf5,0x1,0x1,0x1,0x1,0x1,0x13,0xe,0x15,0xe,0x15,0xe,0x16,0xe,0x15,0xe,0x16,0xe,0x15,0xe,0x1,0x1,0x1,0x1,0x1,0x1,0x1,0x1,0x12,0x0,0x50,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xee,0x0,0x0,0x0,0x0,0x0,0xef,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x7,0x7,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x9b,0x0,0x0,0x0,0x50,0x7,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x12,0x1,0x1,0x1,0x1,0x15,0x1,0x16,0x16,0x16,0xe,0x16,0x16,0x16,0xe,0x16,0x16,0x16,0xe,0x16,0x16,0x15,0x1,0x1,0x1,0x1,0x1,0x13,0x13,0x12,0x0,0xb6,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x50,0x0,0x0,0x0,0x0,0x9d,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x8,0xa,0x0,0x0,0x0,0xa,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xae,0x1,0x1,0x1,0x1,0x15,0xe,0x15,0xe,0x15,0xe,0x16,0xe,0x16,0xf9,0x16,0xf9,0x16,0xf9,0x16,0xe,0x15,0xe,0x15,0x1,0x1,0x1,0x1,0x1,0x12,0x1,0x0,0x52,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xed,0x0,0x0,0x0,0x0,0xa,0x7,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x52,0x0,0x0,0x0,0x0,0x50,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x9b,0x1,0x1,0x1,0x15,0xe,0x16,0x16,0x16,0xe,0x56,0x47,0x96,0x47,0x96,0x46,0x96,0x47,0x56,0xe,0x16,0xe,0x15,0x16,0x15,0x1,0x1,0x1,0x1,0x1,0x12,0xa,0x0,0xb6,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x9b,0x0,0x0,0x0,0x0,0x52,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x42,0x0,0x0,0x0,0x0,0x0,0x9d,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x9,0x45,0x1,0x1,0x15,0xe,0x15,0xe,0x15,0x47,0x56,0x47,0x56,0x57,0x56,0x57,0x56,0x57,0x56,0x47,0x56,0x47,0x16,0xf9,0x15,0xe,0x15,0x1,0x1,0x1,0x1,0x1,0x12,0xa,0x9b,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf6,0x52,0x0,0x0,0x0,0x0,0x9b,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf5,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xae,0x1,0x1,0x15,0x1,0x16,0x16,0x56,0x47,0x96,0x56,0x9e,0x57,0x9e,0x56,0x96,0x57,0x9e,0x56,0x96,0x57,0x96,0x16,0x16,0xe,0x16,0x15,0x15,0x1,0x1,0x1,0x13,0x1,0x10,0x52,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf7,0x9a,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xf5,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf7,0x1,0x1,0xe,0x15,0xe,0x15,0x47,0x56,0x57,0x56,0x57,0x56,0x57,0x5e,0x57,0x5e,0x57,0x56,0x57,0x56,0x47,0x56,0xf9,0x16,0xe,0x15,0x1,0x1,0x1,0x1,0x1,0x13,0xa,0x0,0xf6,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xee,0x0,0x0,0x0,0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf6,0x9b,0xa,0x40,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xf5,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x9d,0x1,0x1,0x15,0x16,0x16,0xe,0x56,0x56,0x9e,0x57,0x5e,0x5e,0x5e,0x9f,0x9e,0x5e,0x9e,0x57,0x9e,0x56,0x96,0x47,0x56,0xe,0x16,0xe,0x15,0x1,0x1,0x1,0x1,0x1,0x12,0x0,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,

        0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xef,0xf5,0xa,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xa,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x5d,0x1,0x15,0xe,0x15,0xe,0x56,0x47,0x56,0x57,0x5e,0x5f,0x9e,0x97,0x9e,0x97,0x9e,0x57,0x5e,0x57,0x56,0x57,0x56,0x47,0x16,0xe,0x15,0xe,0x1,0x1,0x1,0x1,0x13,0x1,0x0,0xae,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xae,0x0,0x0,0x0,0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x9b,0x50,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x50,0xad,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x55,0x1,0x15,0x16,0xe,0x16,0x57,0x96,0x57,0x9e,0x5e,0x9e,0x9f,0xae,0x9e,0xae,0x9f,0x9e,0x9f,0x5e,0x57,0x9e,0x56,0x96,0xf9,0x16,0x16,0x15,0x1,0x1,0x1,0x1,0x1,0x13,0x0,0xf5,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf5,0x0,0x0,0x0,0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x9a,0xa,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xf7,0xef,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x55,0x1,0x15,0xe,0x15,0xe,0x56,0x57,0x56,0x57,0x5e,0x97,0x9e,0x9f,0xae,0x9f,0xae,0x9f,0x9e,0x57,0x56,0x57,0x5e,0x47,0x56,0xe,0x15,0xe,0x15,0x1,0x1,0x1,0x1,0x1,0x0,0xae,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xae,0x0,0x0,0x0,0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xae,0x50,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x12,0x9a,0x7,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x9d,0x1,0x1,0x16,0xe,0x56,0x47,0x96,0x56,0x9e,0x9f,0x9e,0x9e,0xae,0x9f,0xae,0x9e,0xae,0x9f,0x9e,0x5e,0x96,0x57,0x96,0x56,0x16,0xe,0x15,0x1,0x1,0x1,0x1,0x1,0x13,0x0,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xee,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xa,0x9b,0xae,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf7,0x1,0x15,0xe,0x15,0xe,0x56,0x57,0x56,0x57,0x9e,0x9f,0xae,0x9f,0xae,0xaf,0xae,0x9f,0x9e,0x57,0x5e,0x57,0x56,0x47,0x56,0xe,0x15,0xe,0x13,0x1,0x1,0x1,0x1,0x1,0x0,0xef,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xef,0x0,0x0,0x0,0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xae,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x9d,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xae,0x1,0x15,0x16,0xe,0x16,0x47,0x96,0x57,0x9e,0x5e,0x9e,0x9f,0xae,0xae,0xae,0x9f,0xae,0x9e,0x9e,0x57,0x9e,0x56,0x96,0x46,0x16,0x16,0x15,0x1,0x1,0x1,0x1,0x1,0x12,0x12,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x12,0x0,0x0,0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0xf6,0x40,0x0,0x0,0x0,0x0,0x0,0x92,0xf6,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x7,0x1,0x15,0xe,0x15,0xe,0x56,0x57,0x56,0x57,0x5e,0x97,0x9e,0x9f,0xae,0x9f,0xae,0x9f,0x9e,0x5f,0x56,0x57,0x56,0x47,0x16,0xe,0x15,0xe,0x15,0x1,0x1,0x1,0x1,0xa,0xab,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x9b,0x0,0x0,0x0,0x0,0x9d,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0xb5,0x0,0x0,0x0,0x0,0x0,0xf7,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x95,0x1,0x15,0x16,0x16,0xe,0x96,0x56,0x96,0x57,0x5e,0x9e,0x9e,0x9f,0xae,0x9e,0x9e,0x5f,0x5e,0x56,0x9e,0x57,0x96,0xe,0x16,0xe,0x15,0x1,0x1,0x1,0x1,0x1,0x12,0xf7,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xae,0x0,0x0,0x0,0x0,0x5a,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0x52,0x0,0x0,0x0,0x0,0xab,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x9e,0x1,0x1,0x15,0xe,0x56,0x47,0x56,0x57,0x56,0x57,0x9e,0x97,0x9e,0x97,0x9e,0x57,0x5e,0x57,0x56,0x57,0x56,0xf9,0x15,0xe,0x15,0x1,0x1,0x1,0x1,0x1,0x12,0x42,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,0xa,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,0x52,0xf6,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x1,0x15,0xe,0x16,0x16,0x56,0x47,0x96,0x57,0x9e,0x57,0x9e,0x5e,0x9e,0x5f,0x5e,0x56,0x9e,0x57,0x96,0x57,0x16,0xe,0x16,0x16,0x15,0x1,0x1,0x1,0x13,0xa,0xab,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf5,0x0,0x0,0x0,0x0,0xad,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf7,0x12,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,0x9d,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xae,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xae,0x1,0x15,0xe,0x15,0xe,0x56,0x47,0x56,0x57,0x56,0x57,0x56,0x57,0x56,0x57,0x56,0x57,0x56,0x47,0x16,0xe,0x15,0xe,0x15,0x1,0x1,0x1,0x1,0x1,0x0,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x92,0x0,0x0,0x0,0x50,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xa,0x50,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0x92,0x0,0x0,0x0,0xab,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xef,0x0,0x7,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x55,0x1,0x15,0xe,0x15,0x16,0x56,0x47,0x56,0x56,0x96,0x57,0x9e,0x56,0x96,0x57,0x96,0x46,0x56,0xe,0x15,0x16,0x15,0x1,0x1,0x1,0x1,0x1,0x0,0xae,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf6,0x52,0x0,0x0,0x0,0xab,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf7,0x0,0x12,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0x9d,0x0,0x0,0x0,0x9d,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xab,0xa,0x7,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xef,0x1,0xe,0x15,0xe,0x15,0xe,0x16,0x47,0x56,0x47,0x56,0x47,0x96,0x47,0x56,0xf9,0x16,0xe,0x15,0xe,0x15,0xe,0x1,0x1,0x1,0x1,0xa,0x9b,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xef,0x0,0x0,0x0,0x0,0x7,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xef,0x0,0x0,0x52,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x9b,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x0,0x50,0x7,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xae,0x15,0x1,0x15,0xe,0x16,0x16,0x16,0xe,0x56,0x16,0x56,0xe,0x16,0x16,0x16,0xe,0x16,0x16,0x15,0xe,0x13,0x1,0x1,0x1,0x1,0x5b,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x7,0x50,0x0,0x0,0x0,0x7,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x52,0x0,0x0,0x52,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xab,0x0,0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x7,0x0,0x0,0xa,0x7,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xaf,0x1,0xe,0x15,0xe,0x15,0xe,0x15,0xe,0x15,0xe,0x15,0xe,0x15,0xe,0x15,0xe,0x15,0xe,0x1,0x1,0x1,0x1,0xa,0x53,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xef,0x52,0x0,0x0,0xa,0xf7,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x9a,0x0,0x0,0x0,0x50,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x9b,0x0,0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf7,0x0,0x0,0x0,0x0,0x7,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xaf,0x13,0x1,0x15,0x1,0x15,0x16,0x16,0xe,0x15,0xe,0x16,0xe,0x15,0x15,0x15,0x1,0x1,0x1,0x1,0x1,0x1,0x5b,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf7,0x0,0x0,0x0,0x9a,0xf6,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x7,0x40,0x0,0x0,0x0,0x52,0x9d,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf7,0xa,0x0,0x0,0xf7,0x7,0xff,0xff,0xff,0xff,0xff,0xf6,0x7,0xf7,0x0,0x0,0x0,0x0,0x52,0x53,0x7,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf6,0x95,0x1,0x1,0x1,0x15,0xe,0x15,0x1,0x15,0xe,0x15,0x1,0x13,0x1,0x1,0x1,0x1,0x1,0x52,0xae,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x9b,0x50,0x0,0x0,0x53,0xf5,0xef,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xee,0xf7,0x12,0x0,0x0,0x0,0x53,0x7,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf7,0x52,0x0,0x0,0x5b,0x9b,0x5b,0x9b,0x5b,0x9a,0x0,0x0,0x0,0x50,0x9b,0xf5,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x7,0x55,0x1,0x1,0x13,0x15,0x15,0x1,0x15,0x1,0x1,0x1,0x1,0x1,0x1,0x1,0xf7,0xef,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xef,0xf7,0x5a,0x0,0x0,0x10,0x12,0x9b,0x5b,0x9b,0x5b,0x9a,0x12,0x0,0x0,0x0,0x5b,0xf7,0x7,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf6,0xff,0xae,0x9a,0xa,0x40,0x40,0x40,0x13,0x9b,0xae,0xff,0xf6,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xef,0x9d,0x1,0x1,0x1,0x1,0x1,0x1,0x1,0x1,0x1,0x53,0xae,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xef,0x7,0xf7,0x9b,0x53,0x52,0x42,0x50,0x53,0x9b,0xf7,0xff,0xf6,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x7,0xae,0x7,0xae,0x7,0x7,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff
        };
/*        0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
        0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff
        };
/*        };        

*/
					
void Draw_Background(unsigned char color)
{
 	 int  i;
	
     spi_command(PASET);   // page start/end ram
     spi_data(2);       // for some reason starts at 2
     spi_data(131);          
  
     spi_command(CASET);   // column start/end ram
     spi_data(0);          
     spi_data(131);

	 // write some stuff (background)
     spi_command(RAMWR);    
	 //printf("  Write 18000\n");
     for (i = 0; i < 18000; i++){
         spi_data(color);  // 28 is green
         }
}

void Initialize_Nokia_LCD(void) 
{  
    unsigned int   i = 0;
  
    //printf("  Init SPI\n");
//    Init_SPI_Master();
	DDRB |= ((1<<PB5)|(1<<PB7)|(1<<PB3)|(1<<PB2));
//	PORTB |= 0xAC;  // Set bits MOSI & SCK
 	 SetBit(PORTB,PINB2);	 // Set Reset high
 	 SetBit(PORTB,PINB3);	 // Set Chip Select high
 	 SetBit(PORTB,PINB5);	 // Set DIO high
 	 SetBit(PORTB,PINB7);	 // Set Clock high

	//printf("  Delay 20ms\n");
    shortdelay(10000);

//    ClrBit(PORTB,PINB2);
	
    //printf("  Reset LCD\n");
    shortdelay(1000);
//    IOSET0 |= LCD_RESET;
    SetBit(PORTB,PINB2);
    shortdelay(20000);

	ClrBit(PORTB,PINB3);
    //printf("  Set Display Control\n");
    spi_command(DISCTL);  // display control
    spi_data(0x03);
    spi_data(32);
    spi_data(12);
//    spi_data(0x00);

    spi_command(COMSCN);  // comscn
    spi_data(0x01);

    spi_command(OSCON);  // oscon

    spi_command(SLPOUT);  // sleep out

    spi_command(VOLCTR);  // electronic volume, this is kinda contrast/brightness
    spi_data(0xff);//ff);     //  this might be different for individual LCDs
    spi_data(0x01);//01);     //

    spi_command(PWRCTR);  // power ctrl
    spi_data(0x0f);       //everything on, no external reference resistors
    shortdelay(10000);

    spi_command(DISINV);  // display mode

    spi_command(DATCTL);  // datctl
    spi_data(0x00);
    spi_data(0);
    spi_data(0x01);
//    spi_data(0x00);

	//printf("  Setup color table\n");
    spi_command(RGBSET8);   // setup color lookup table
    // color table
    //RED
    spi_data(0);
    spi_data(2);
    spi_data(4);
    spi_data(6);
    spi_data(8);
    spi_data(10);
    spi_data(12);
    spi_data(15);
    // GREEN
    spi_data(0);
    spi_data(2);
    spi_data(4);
    spi_data(6);
    spi_data(8);
    spi_data(10);
    spi_data(12);
    spi_data(15);
    //BLUE
    spi_data(0);
    spi_data(4);
    spi_data(9);
    spi_data(15);

    spi_command(NOPP);  // nop

	Draw_Background(28);
  
    spi_command(DISON);   // display on

    shortdelay(20000);

	Nokia_LED(ON);
	
//	printf("  Adjust contrast\n"); 
    //Cycle_LCD();

	//printf("  Finished with LCD\n");
}

void Nokia_LCD_ContrastUp()
{
 	spi_command(VOLUP);
//    spi_command(VOLCTR);  // electronic volume, this is kinda contrast/brightness
//    spi_data(contrast);//ff);       //  this might be different for individual LCDs
//    spi_data(0x01);//01);     //
}

void Nokia_LCD_ContrastDown()
{
 	spi_command(VOLDOWN);
//    spi_command(VOLCTR);  // electronic volume, this is kinda contrast/brightness
//    spi_data(contrast);//ff);       //  this might be different for individual LCDs
//    spi_data(0x01);//01);     //
}
void Draw_Color_Bars(unsigned char color)
{
    int i;
	
    // Draw a multi-colored square in the center of screen
	//printf("  Draw box 4096\n");
    for(i=0; i<4096; i++) 
        LCD_put_pixel(i, (i % 64) + 32, (i / 64) + 32);
}

void Nokia_LCD_LED(unsigned char state)
{
    if(state==ON)  SetBit(PORTD,PIND2);
	else ClrBit(PORTD,PIND2);
}

void Draw_Alphabet()
{
 	unsigned char offset;
	
	offset = 12;
	LCD_Puts(10,110,"0123456789.0",0x03);
	LCD_Puts(10,110-offset*1,"ABCDEFGHIJKL",0x03);
	LCD_Puts(10,110-offset*2,"MNOPQRSTUVWX",0x03);
	LCD_Puts(10,110-offset*3,"YZabcdefghij",0x03);
	LCD_Puts(10,110-offset*4,"klmnopqrstuv",0x03);
	LCD_Puts(10,110-offset*5,"wxyz~!@#$%^&",0x03);
	LCD_Puts(10,110-offset*6,"*()_+-=;:'<>",0x03);
	LCD_Puts(10,110-offset*7,",./?` |",0x03);
}

void Draw_Boxes(unsigned char color)
{	
	//printf("  Draw box empty\n");
	Draw_Box(0,0,129,129,color);
	Draw_Box(2,2,120,120,color);
	Draw_Box(10,10,110,110,0xe0);
	Draw_Box(20,20,100,100,0x03);
	//Draw_Box(2,2,120,120,28);
	//Draw_Box(10,10,110,110,28);
	//Draw_Box(20,20,100,100,28);
}

void Draw_Box_Filled(unsigned char xstart,unsigned char ystart,
	 				 unsigned char xend,unsigned char yend,unsigned char color)
{
     int i,j;
	 
	 for(j=ystart; j<=yend; j++) 
	     for(i=xstart; i<=xend; i++)   
 	         LCD_put_pixel(color,128-i,128-j);
}

void Draw_SOC_Logo(unsigned char x,unsigned char y)
{
 	 int i,j;
	 
	 for(j=0; j<65; j++) 
	     for(i=0; i<128; i++)   
 	         LCD_put_pixel(*(bmp_logo_image+i+((65-j)*127)),128-(x+j),128-(y+i));
}

void Display_Gravity2()
{
    unsigned char firstmeasurement;
	char outstrg[30];
    int i,xgrav,ygrav,zgrav,xmin,xmax;
	int xgravity,ygravity,zgravity;
	float gravity,xaccel,yaccel,force,bforce,cforce,dforce,fforce,roll,pitch;
	float xfgrav,yfgrav,zfgrav;
	
	Init_3Axis_Accelerometer(G15MODE);
	Draw_Background(0xff);
	LCD_Puts(1,114,"SOC Robotics",0x00);
	LCD_Puts(4,90,"Acceleration",0x00);
	LCD_Puts(4,74,"x axis = ",0x00);
	LCD_Puts(4,60,"y axis = ",0x00);
	LCD_Puts(4,46,"z axis = ",0x00);
	LCD_Puts(4,26,"Press right to",0x00);
	LCD_Puts(4,12,"exit",0x00);

	while(1) {
		xgravity = ygravity = zgravity = 0;	
		for(i=0; i<1; i++) {
			xgravity += AnalogCh(5,EXTERNALREF);
			ygravity += AnalogCh(0,EXTERNALREF);
			zgravity += AnalogCh(1,EXTERNALREF);
			}

		xgravity = (xgravity/1);
		ygravity = (ygravity/1);
		zgravity = (zgravity/1);

		sprintf(outstrg,"%4d   ",xgravity);
		LCD_Puts(70,74,outstrg,0x00);
		sprintf(outstrg,"%4d   ",ygravity);
		LCD_Puts(70,60,outstrg,0x00);
		sprintf(outstrg,"%4d   ",zgravity);
		LCD_Puts(70,46,outstrg,0x00);
		}
}

//  The switches are connected to the parallel input of an 74HC165.  To read
//  current state of switches - load current state - default is high if 
//  switch not pressed (pull up resistor on each switch).  Then shift 8 times
//  to get current switch states.  Return value with SW7 at bit 6, SW1 at
//  bit 0.
//  Note:  Wasp A uses PC2 for clock and reads serial data on PC3
//         Wasp B uses PD6 for clock and reads serial data on PD7
unsigned char Read_Switches()
{
 	unsigned char switchvalues;
    int i;
	
	SetBit(PORTD,PIND6);  // Setup initial clk
	
	SetBit(PORTD,PIND3);  // Load Switch values - low to high transition
    ClrBit(PORTD,PIND3);
	SetBit(PORTD,PIND3);

	//  Shift data out 8 times to get all the switch values
	//  Switch value bit 8 is always high
	switchvalues = 0x00;
	for(i=0; i<8; i++) {
		if(i>0)  switchvalues = (switchvalues<<1);
	    ClrBit(PORTD,PIND6);
		SetBit(PORTD,PIND6);
		if(!(PIND&(1<<PIND7)))  switchvalues |= 0x01;
	    }
	return switchvalues;
}

// Nokia Color LCD display functions
void ProcessLCDCommands(unsigned char inchar)
{
	char outstrg[30],LCD_Switches;
	unsigned char inbytes[5],toggle,slaverx,firstmeasurement,numaxis;
	int ylocation,centerpressed,cursorlocation;
	long xgravity,ygravity,loopcount,ivalue,bvalue,cvalue;
	float gravity,xaccel,yaccel,force,bforce,cforce,dforce,fforce,roll,pitch;
	int i,icnt,j,loopsetting,loopmode,blackfinresetmode,countervalue,numbr;
	int loopmode2,num1,num2,xgrav,ygrav,xmin,xmax,iforce,dataoutputperiod;
	
	switch (inchar) {
					    case '1':
						    printf("4\nTurn LCD contrast up");
						    Nokia_LCD_ContrastUp();
							printf("\n-");
							break;
					    case '2':
						    printf("5\nTurn LCD contrast down");
						    Nokia_LCD_ContrastDown();
							printf("\n-");
							break;
					    case '6':
						    printf("6\nTurn LCD LED on");
						    Nokia_LCD_LED(ON);
							printf("\n-");
							break;
					    case '7':
						    printf("7\nTurn LCD LED off");
						    Nokia_LCD_LED(OFF);
							printf("\n-");
							break;
						case 'n':
						    putcharr('n');
							printf("\nInitialize Nokia LCD display\n");
							Initialize_Nokia_LCD();
							printf("\n-");
							break;							
						case '8':
						    putcharr('8');
							printf("\nSwitch values=");
							printf("%x",Read_Switches());
							printf("\n-");
							break;							
						case '9':
						    putcharr('9');
							printf("\nDisplay SOC Logo\n");
							ylocation = 0;
							while(!(inchar=getcharnw())) {
							    Draw_SOC_Logo(ylocation+1,0);
							    Draw_Box_Filled(ylocation,0,ylocation,128,28);
								ylocation++;
								if(ylocation==40) {
								    ylocation = 0;
									Draw_Box_Filled(40,0,110,128,28);
									}
								}
							printf("\n-");
							break;							
						case '4':
						    printf("4\nOutput numbers continuously");
							printf(" - press any key to exit\n");
							ivalue = 0;
							bvalue = 34;
							cvalue = 34;
							gravity = 0.0;
							bforce = 23.12;
							cforce = 34.23;
							dforce = 54.34;
							Draw_Background(0xff);
							while(!(inchar=getcharnw())) {
								sprintf(outstrg,"%#6.2f",dforce);
								dforce -= 0.03;
								LCD_Puts(50,99,outstrg,0x03);
								sprintf(outstrg,"%6d",cvalue++);
							    LCD_Puts(50,85,outstrg,0x03);
								sprintf(outstrg,"%#6.2f",cforce);
								cforce += 0.54;
								LCD_Puts(50,72,outstrg,0x03);
								sprintf(outstrg,"%#6.2f",bforce);
								bforce += 0.34;
								LCD_Puts(50,59,outstrg,0x03);
								sprintf(outstrg,"%6d",bvalue++);
							    LCD_Puts(50,46,outstrg,0x03);
								sprintf(outstrg,"%6d",ivalue++);
							    LCD_Puts(50,33,outstrg,0x03);
								sprintf(outstrg,"%#6.2f",gravity);
								gravity += 0.12;
								LCD_Puts(50,20,outstrg,0x03);
								}
							printf("\n-");
							break;
						case 'm':
							Draw_Menu_Command();
							break;
						case '5':
						    printf("4\nDraw alphabet");
							Draw_Background(0xff);
							Draw_Alphabet();
							printf("\n-");
							break;
						case '3':
						    Draw_Boxes_Continuously();
							printf("\n-");
							break;
						case 'u':
							loopsetting += 100;
							break;
						case 'q':
							printf("\nOutput gravity continuously\n");
							firstmeasurement = YES;
							Draw_Background(0xff);
							LCD_Puts(1,114,"SOC Robotics",0x03);
							LCD_Puts(4,90,"Roll =  ",0x03);
							LCD_Puts(4,74,"Pitch = ",0x03);
							while(!(inchar=getcharnw())) {
				   	 		    xgravity = ygravity = 0;
								mseccountdown3 = 1000;
								for(i=0; i<10; i++) {
								   xgravity += AnalogCh(0,INTERNALREF);
								   ygravity += AnalogCh(1,INTERNALREF);
								   }
							    xgrav = xgravity/10;
							    ygrav = ygravity/10;
								if(firstmeasurement==YES) {
								    xmin = xmax = xgrav;
									firstmeasurement = NO;
									}
							    if(xgrav<xmin)  xmin = xgrav;
							    if(xgrav>xmax)  xmax = xgrav;
								xaccel = xgrav-515;
								xaccel /= 60.0;
								//for(i=0; i<10; i++) {
								//	yaccel = sin(.45);
								//	yaccel = cos(.45);
								//	}
								yaccel = ygrav-511;
								yaccel /= 62.0;
								roll = asin(xaccel)*57.2957;
								pitch = asin(yaccel)*57.2957;
//							    printf(" g=%3d %3d   %3d %3d  %.3f %.3f    \r",
//								          xgrav,ygrav,xmin,xmax,xaccel,yaccel);
							    //printf(" g=%#7.3f %#7.3f  r/p=%#7.3f %#7.3f  \r",
								//          xaccel,yaccel,roll,pitch);
								sprintf(outstrg,"%#6.2f",roll);
								LCD_Puts(70,90,outstrg,0x03);
								sprintf(outstrg,"%#6.2f",pitch);
							    LCD_Puts(70,74,outstrg,0x03);
								//printf(" g=%x %x %d   \r",vlow,vhigh,xgrav);
							    }
							printf("\n-");
							break;
			 //Display_Gravity();
			 //Draw_Menu_Command();
			 //Draw_Background(0xff);
			 //Draw_Alphabet();
			 //Draw_Boxes_Once();
			 //Draw_Background(0x00);
			 //Draw_SOC_Logo(ylocation+1,0);
			 //Cycle_LCD();
					    case 'f': case 'F':
						    putcharr('f');
							printf("\nForce sensor output:\n");
							Draw_Background(0xff);
							LCD_Puts(1,114,"SOC Robotics",0x03);
							LCD_Puts(4,90,"Force =  ",0x03);
							while(!(inchar=getcharnw())) {
				   	 		    iforce = AnalogCh(7,EXTERNALREF);
								//force = (1024.0 - iforce);
								//if(iforce>840) force = 1.0 + 0.0125*(185.0-force);
								//else force = 3.3*(1/force);
								force = iforce * 0.00414;
								fforce = iforce*1.0;
								bforce = 3.83e-5*(fforce*fforce);
								cforce = -8.9522e-8*(fforce*fforce*fforce);
								dforce = 5.9e-11*(fforce*fforce*fforce*fforce);
								force = 0.31+bforce+cforce+dforce;
								if(iforce<2) force = 0.0;
								printf(" f=%3d %#7.3f lbs      \r",iforce,force);
//								printf(" f=%d %.3f lbs  %f %f %f %f    \r",
//								      iforce,force,fforce,bforce,cforce,dforce);
								sprintf(outstrg,"%#7.3f",force);
								LCD_Puts(55,90,outstrg,0x03);
							    }
							printf("\n-");
							break;
							}
			 if((mseccountdown2==0)&&(0)) {
			 		//inchar = Read_Switches();
			 		//sprintf(outstrg,"%d",inchar);
					//LCD_Puts(4,20,"Switch = ",0x00);
					//LCD_Puts(70,20,outstrg);
			      	switch(Read_Switches()) {
			            case SWITCH_RIGHT: 
					        if(LCD_Switches&SWITCH_RIGHT)  {
						        Nokia_LCD_LED(ON);
							    LCD_Switches &= ~SWITCH_RIGHT;
							    }
						    else {
						        Nokia_LCD_LED(OFF);
							    LCD_Switches |= SWITCH_RIGHT;
							    }
							mseccountdown2 = 440;
						    break;
						case SWITCH_UP: 
							if(centerpressed==YES) {
							    Draw_Menu_Command();
								centerpressed = NO;
								}
						    LCD_Puts(1,113-cursorlocation*13," ",0x03);
							if(cursorlocation--==0) cursorlocation = 6;
						    LCD_Puts(1,113-cursorlocation*13,">",0x03);
							mseccountdown2 = 190;
							break;
						case SWITCH_DOWN: 
							if(centerpressed==YES) {
							    Draw_Menu_Command();
								centerpressed = NO;
								}
						    LCD_Puts(1,113-cursorlocation*13," ",0x03);
							if(cursorlocation++==6) cursorlocation = 0;
						    LCD_Puts(1,113-cursorlocation*13,">",0x03);
							mseccountdown2 = 190;
							break;
						case SWITCH_CENTER: 
						    switch(cursorlocation) {
								case 0:
								    break;
								case 1:
						    		centerpressed = YES;
								    Draw_Background(0xff);
									Draw_Color_Bars(28);
									Draw_Boxes(38);
								    break;
								case 2:
									centerpressed = YES;
									Draw_Background(0xff);
									Draw_Alphabet();
								    break;
								case 3:
								    break;
								case 4:
									centerpressed = YES;
									Display_Gravity();
								    break;
								case 5:
								    centerpressed = YES;
									//Draw_Background(0xff);
									Draw_SOC_Logo(ylocation+1,0);
								    break;
								case 6:
								    centerpressed = YES;
									Draw_Background(0xff);
								    break;
							    }
							break;
						case SWITCH_MIDRIGHT: 
						    Draw_Box_Filled(110,10,120,20,03);
							break;
						case SWITCH_MIDLEFT: 
						    Draw_Box_Filled(110,10,120,20,0xFF);
							break;
					    }
			   		}
} 				

void Display_Gravity()
{
    unsigned char firstmeasurement;
	char outstrg[30],inchar;
    int i,xgrav,ygrav,zgrav,xmin,xmax;
	long xgravity,ygravity,zgravity;
	float gravity,xaccel,yaccel,force,bforce,cforce,dforce,fforce,roll,pitch;
	float xfgrav,yfgrav,zfgrav;
	
	Init_3Axis_Accelerometer(G15MODE);
	firstmeasurement = YES;
	Draw_Background(0xff);
	LCD_Puts(1,114,"SOC Robotics",0x00);
	LCD_Puts(4,90,"Acceleration",0x00);
	LCD_Puts(4,74,"x axis = ",0x00);
	LCD_Puts(4,60,"y axis = ",0x00);
	LCD_Puts(4,46,"z axis = ",0x00);
	LCD_Puts(4,26,"Press right to",0x00);
	LCD_Puts(4,12,"exit",0x00);

	while(1) {
		xgravity = ygravity = zgravity = 0;
		for(i=0; i<10; i++) {
			xgravity += AnalogCh(5,EXTERNALREF);
			ygravity += AnalogCh(0,EXTERNALREF);
			zgravity += AnalogCh(1,EXTERNALREF);
			}
			
		xgravity = xgravity/10;
		ygravity = ygravity/10;
		zgravity = zgravity/10;
		
		xfgrav = ((float)(512.0 - xgravity))/250.0;
		yfgrav = ((float)(512.0 - ygravity))/250.0;
		zfgrav = ((float)(512.0 - zgravity))/250.0;
		
		sprintf(outstrg,"%#6.3f",xfgrav);
		LCD_Puts(66,74,outstrg,0x00);
		sprintf(outstrg,"%#6.3f",yfgrav);
		LCD_Puts(66,60,outstrg,0x00);
		sprintf(outstrg,"%#6.3f",zfgrav);
		LCD_Puts(66,46,outstrg,0x00);
		inchar = Read_Switches();
		if(inchar==SWITCH_DOWN) break;
		if(inchar==SWITCH_UP) break;
		}
}

