/**************************************************************

   Program Title:  Wasp AVR Monitor
   
   Program Name:  Wasp_ISRs.c		  Version: 0.85
   
   Author:  SS	  					  Date:  August 10, 2005
   
   Compiled with ImageCraft ICCAVR Standard V7.13A.
   
   This file contains routines that implement the interrupt service routines 
   for the Wasp Monitor.
   
   Copyright 2004-2009, SOC Robotics, Inc.  All rights reserved.
   
****************************************************************/
/*
 * Copyright 2004-2009, SOC Robotics, Inc.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the copyright holders nor the names of
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 * 4. Redistribution is only allowed in combination with SOC Machines, 
 *    Inc. hardware products.
 *
 * THIS SOFTWARE IS PROVIDED BY SOC ROBOTICS, INC. AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL OC MACHINES, 
 * INC. OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * For additional information see http://www.soc-robotics.com
 */

/*
 * $Log: Wasp_ISRs.c,v $
 * Revision 0.86  2006/02/07 16:40:20  SS
 *    2-wire interface, 8MHz clock, AVR Flash writer, XON/XOFF, 38,700baud
 * Revision 0.52  2005/06/04 18:36:42  SS
 * Preview release
 *
 */
#include <iom644v.h>
#include <macros.h>
#include <string.h>
#include <stdlib.h>
#include <stdio.h>
#include "Wasp_Uart.h"
#include "Wasp_Defines.h"
#include "Wasp_Extern.h"

// Vector numbers for ATmega16
//#pragma interrupt_handler UART_RX_Interrupt:12 UART_TX_Interrupt:13
// Vector numbers for ATmega32
//#pragma interrupt_handler UART_RX_Interrupt:14 UART_TX_Interrupt:16
// Vector numbers for ATmega644
#pragma interrupt_handler UART_RX_Interrupt:iv_USART0_RX
#pragma interrupt_handler UART_TX_Interrupt:iv_USART0_UDRE
#pragma interrupt_handler TIMER0_Compare_Interrupt:iv_TIMER0_COMPA
#pragma interrupt_handler TIMER2_Compare_Interrupt:iv_TIMER2_COMPA

//*********************************************************
//*********************************************************
//     Interrupt handlers
//*********************************************************
//*********************************************************

//  USART serial receiver interrupt handler
//  Flow control by XON/XOFF
void UART_RX_Interrupt(void)
{
	unsigned char data,tmphead;
	
	data = UCSR0A;
	if((data&0x10)) frameerror = YES;
	if((data&0x08)) dataoverrun = YES;
	
	data = UDR0;   // read the received data
	
	tmphead = (UART_RxHead+1)&UART_RX_BUFFER_MASK;  // calculate buffer index
	UART_RxHead = tmphead;      // store new index
	UART_RxBuf[tmphead] = data; // store received data in buffer
	
	rxcnt++;
	if(rxcnt>UART_RX_BUFFER_SIZE-1) rxcnt = UART_RX_BUFFER_SIZE-2;
	
	totalrxcnt++;
	if(rxcnt>rxcntmax)  rxcntmax = rxcnt;

	// If receive buffer almost full Fire TX interrupt if 
	// transmit buffer empty otherwise alert Tx int routine XOFF must go
	if((rxcnt>(UART_RX_BUFFER_SIZE-30))&&(xoffsent==NO))  {
	    if((UCSR0A&0x20))  UCSR0B |= (1<<UDRIE0);
		else sendxoff = YES;
		}
	
//	if((rxcnt>(UART_RX_BUFFER_SIZE-10))&&(xoffsent==NO)&&(enablexonoff==YES)) {
//	if((rxcnt>(UART_RX_BUFFER_SIZE-10))&&(xoffsent==NO)) {
	// If tx buffer is empty then transmit xoff else signal tx to send xoff
//	    sendxonxoff = YES;
//		xoffsent = YES;
//		UCSRB |= (1<<UDRIE);  // Fire TX interrupt	
//		}
}

//  UART transmit interrupt handler
//  Flow control by XON/XOFF
void UART_TX_Interrupt(void)
{
	unsigned char tmptail;

	// Check if all data has been transmitted
	if(UART_TxHead != UART_TxTail)  {
	    // Check chars in rx buffer - if too many - transmit XOFF
		if((rxcnt>(UART_RX_BUFFER_SIZE-34))&&((xoffsent==NO)||(sendxoff==YES))){
		    UDR0 = XOFF;
			xoffcnt++;
			xoffsent = YES;
			sendxoff = NO;
			}
		else if((rxcnt<5)&&(xoffsent==YES)) {
		    UDR0 = XON;
			xoncnt++;
			xoffsent = NO;
		    }
		else {
			 // Calculate buffer index
			 tmptail = (UART_TxTail + 1) & UART_TX_BUFFER_MASK;
			 UART_TxTail = tmptail;     // Store new index
			 UDR0 = UART_TxBuf[tmptail]; // Start transmission
//			 if(UART_TxBuf[tmptail]==XON) {
//			 	  xoffsent = NO;
//				  xonsent = NO;
//				  }
			 }
		}
	else  {  // Check chars in rx buffer - if too many trans XOFF
		if((rxcnt>(UART_RX_BUFFER_SIZE-34))&&(xoffsent==NO)) {
		    UDR0 = XOFF;
			xoffsent = YES;
			xoffcnt++;
			}
		else if((rxcnt<5)&&(xoffsent==YES)) {
		    UDR0 = XON;
			xoncnt++;
			xoffsent = NO;
		    }
		else UCSR0B &= ~(1<<UDRIE0); // Disable UDRE interrupt
		}
}

//  Timer0 interrupts every msec - This routines decrements 
//  countdown timers - other routines can control timing to 
//  within 1 msec by monitoring these software timers
void  TIMER0_Compare_Interrupt(void)
{
 	if(mseccountdown1>0)  mseccountdown1--;
 	if(mseccountdown2>0)  mseccountdown2--;
	if(mseccountdown3>0)  mseccountdown3--;
	if(flashcountdown>0)  flashcountdown--;
}

//  Real Time Clock interrupts every 4msec - This routine decrements 
//  countdown timers and maintains the watch clock
void  TIMER2_Compare_Interrupt(void)
{
 	if(rtccountdown1>0)  rtccountdown1--;
 	if(rtccountdown2>0)  rtccountdown2--;
	if(rtccountdown3>0)  rtccountdown3--;
	if(rtccountdown4>0)  rtccountdown4--;
	
//	if(!(rtcclockcnt++)) {
	if(rtcclockcnt++==0) {
	    //rtcclockcnt = 0;
	    if(seconds++>=59) {
		    seconds = 0;
			if(minutes++>=59) {
			    minutes = 0;
				if(hours++>=23) {
				    hours = 0;
					days++;
					}
				}
			}
		}
}
