/**************************************************************

   Program Title:  Wasp AVR Monitor
   
   Program Name:  Wasp_TWI.c	Version: 0.85
   
   Author:  SS	  			    Date:  August 10, 2005
   
   Compiled with ImageCraft ICCAVR Standard V7.13A.
   
   This file contains routines that implement an TWI Master and Slave
   interrupt driven controller.
   
   Copyright 2004-2009, SOC Robotics, Inc.  All rights reserved.
  
****************************************************************/
/*
 * Copyright 2004-2009, SOC Robotics, Inc.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the copyright holders nor the names of
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 * 4. Redistribution is only allowed in combination with SOC Machines, 
 *    Inc. hardware products.
 *
 * THIS SOFTWARE IS PROVIDED BY SOC ROBOTICS, INC. AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL OC MACHINES, 
 * INC. OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * For additional information see http://www.soc-robotics.com
 */

/*
 * $Log: Wasp_TWI.c,v $
 * Revision 0.86  2006/02/07 16:40:20  SS
 *    2-wire interface, 8MHz clock, AVR Flash writer, XON/XOFF, 38,700baud
 * Revision 0.52  2005/06/04 18:36:42  SS
 * Preview release
 *
 */
#include <iom644v.h>
#include <macros.h>
#include <string.h>
#include <stdlib.h>
#include <stdio.h>
#include "Wasp_Uart.h"
#include "Wasp_Defines.h"
#include "Wasp_Extern.h"

// Initialize the TWI Master interface I2C
//  TBD - pull the default slave address from EEPROM
//        otherwise use default
void  Init_TWI_Master(void)
{
 	  TWBR = 2;  // Set bit rate to about 100K with 8MHz clock
	  TWCR = (1<<TWINT)|(1<<TWEN);  // Turn 2 wire port on  SDA - PC1, SCL - PC0
}

// Initialize the TWI Slave interface I2C
//  Set TWI slave address and optionally General Call
void  Init_TWI_Slave(unsigned char slaveaddress,char generalcall)
{
 	  if(generalcall) TWAR = (slaveaddress<<1) | TWGCE;
	  else TWAR = (slaveaddress<<1);
	  // Turn 2 wire port on, enable slave address recognition,
	  // clear TWINT bit -  SDA - PC1, SCL - PC0
	  TWCR = (1<<TWINT)|(1<<TWEA)|(1<<TWEN);  
}

void TWI_Error(void)
{
}

void TWI_Off(void)
{
 	 TWCR = (1<<TWINT);  // Reset TWI - this allows SDA to go high
}

// Transmit one byte to slave processor via 2-wire interface
unsigned char  TWI_Transmit(unsigned char slaveaddress, unsigned char txdata,
                            unsigned char statusmode)
{
      unsigned char twistatus1,twistatus2,twistatus3;
	  int countervalue;
	  
	  twistatus1=twistatus2=twistatus3 = 0;

	  // Send start command and wait for completion
	  TWCR = (1<<TWINT)|(1<<TWEN)|(1<<TWSTA);
	  while(!(TWCR & (1<<TWINT)))  ;	
	  twistatus1 = TWSR;
	  // Send slave address and write command 
	  TWDR = (slaveaddress<<1) | SLA_W;
	  TWCR = (1<<TWINT)|(1<<TWEN);
	  while(!(TWCR & (1<<TWINT)))  ;  
	  twistatus2 = TWSR; 
	  // Send data byte and wait for transmission to complete
	  TWDR = txdata;    
	  TWCR = (1<<TWINT)|(1<<TWEN);
	  countervalue = 0;
	  while(!(TWCR & (1<<TWINT))) {
//		  if(countervalue++>90) break;
		  } 	 
	  twistatus3 = TWSR;
/*	  // Send second data byte and wait for transmission to complete
	  TWDR = 0x45;    
	  TWCR = (1<<TWINT)|(1<<TWEN);
	  countervalue = 0;
	  while(!(TWCR & (1<<TWINT))) {
		  if(countervalue++>40) break;
		  } 	 
	  twistatus3 = TWSR;
*/
	TWCR = (1<<TWINT)|(1<<TWEN)|(1<<TWSTO); 
	  // Optionally output status bytes
	  if((txdata!=0x55)&(statusmode==VERBOSE)) 
	   printf("\nTWI status bytes = %x %x %x",twistatus1,twistatus2,twistatus3); 
	  
	  // Send stop command
//	  if(countervalue>90) return 0x02;
//	  else TWCR = (1<<TWINT)|(1<<TWEN)|(1<<TWSTO); 

	  return 0x01;  // OK
}

// Receive one byte from slave processor via 2-wire interface
unsigned char TWI_Master_Receive(unsigned char slaveaddress)
{
 	  unsigned char rxdata;
	  
	  rxdata = 0;
 	  TWCR = (1<<TWINT)|(1<<TWEN)|(1<<TWSTA);  // Send start condition
	  while(!(TWCR & (1<<TWINT)))  ;	  // Wait for TWINT flag - start done
	  //if((TWSR & 0xF8) != TWI_START) twi_error();  // See if Start condition
	  TWDR = (slaveaddress<<1) | SLA_R;	 // Request data command
	  TWCR = (1<<TWINT)|(1<<TWEN);		  
	  while(!(TWCR & (1<<TWINT)))  ;	  // Wait for ACK/NACK 
	  if((TWSR & 0xF8) != MT_SLA_ACK) TWI_Error();  // See if ACK/NACK received  

	  TWCR = (1<<TWINT)|(1<<TWEA)|(1<<TWEN);
	  while(!(TWCR & (1<<TWINT)))  ; 	  // Wait for reception to complete
	  rxdata = TWDR;      			  	  // Send data byte 
	  
	  // Get next receive byte
	  /*
	  TWCR = (1<<TWINT)|(1<<TWEN);
	  countervalue = 0;
	  while(!(TWCR & (1<<TWINT))) {
		 if(countervalue++>40) break;
		 } 	
	  inbyte = TWDR;    
	  twistatus4 = TWSR;
	  */
	  
	  //if((TWSR & 0xF8) != MT_DATA_ACK) TWI_Error();  // See if data received
	  TWCR = (1<<TWINT)|(1<<TWEN)|(1<<TWSTO);   // transmit stop
	  return rxdata;
}
								
void  TestTWI(void)
{
	TWI_Transmit(0x15,0x55,QUIET);
	TWI_Transmit(0x15,0xaa,QUIET);
}

void TWI_Write_Slave()
{
    unsigned char inchar,twistatus1,twistatus2,twistatus3;
	int countervalue;
	
    printf(" TWI Master Write Active\n");
	Init_TWI_Master();
	printf("Enter character ['e'-exit z-sumo1]: ");
	while((inchar=getcharr())!='e')  {
	    countervalue = 0;
		putcharr(inchar);
		// Output byte on TWI continuously
		if(inchar=='z') {
			printf("Press 'e' to exit");
			}
		if(inchar=='r') {
		    while(!(inchar=getcharnw()))  {
			    if(TWI_Transmit(0x15,0x55,VERBOSE)!=0x01) {
		            TWI_Off();
		            Init_TWI_Master();
		            }
			    }
			}
		else {
		    if(TWI_Transmit(0x15,inchar,VERBOSE)!=0x01) {
		        TWI_Off();
		        Init_TWI_Master();
		        }
			}
        printf("\nEnter character('e' to exit): ");
	    }
	TWI_Off();
	printf("\n");
}

