/**************************************************************************
 **************************************************************************
 
  Program:  Gstep_TWI_Functions		Date: December 29, 2008
 
  Author:  S. Swift		    		Version: 1.77
  
  Copyright 2002-2009 SOC Robotics, Inc.
 
  TWI Functions for handling peripherals such as Motors, DRO's, joysticks
  etc.
		 
 ***************************************************************************	 
 ***************************************************************************/
#include <iom644v.h>
#include <macros.h>
#include <ctype.h>
#include <string.h>
#include <math.h>
#include <stdlib.h>
#include <eeprom.h>
#include <stdio.h>

//#include "uart.h"
#include "Wasp_Uart.h"
#include "Wasp_Defines.h"
#include "Wasp_Extern.h" 

// ***********************************************************************
// ***********************************************************************
//     Start of Code
// ***********************************************************************
// ***********************************************************************


#define	   TWI_MTX_ADR_NACK  0x20

// Configure SmartLCD display device via TWI to accept float
void  Init_SmartLCD_TWI(unsigned char twiaddress)
{
	 messageBuf[0] = 'm';
	 messageBuf[1] = 'd';
	 TWI_Start_Write(twiaddress,messageBuf,2);
}

// Start a measurement event in the Digital Compass
void  Init_DigitalCompass_TWI()
{
	 messageBuf[0] = 'A';
	 TWI_Start_Write(DIGITALCOMPASSTWIADDRESSWR,messageBuf,1);
}

void Write_DigitalCompass_Register(unsigned char twiaddress,unsigned char outbyte)
{
    messageBuf[0] = outbyte;
    TWI_Start_Write(twiaddress,messageBuf,1);
}

unsigned char Read_DigitalCompass_Register(unsigned char twiaddress,unsigned char iregister)
{
	TWI_Start_Read(twiaddress,iregister);
    TWI_Get_Data_From_Transceiver(messageBuf,1);
    return messageBuf[0];
}

int Read_DigitalCompass_Heading()
{
	union {
	    unsigned char tempbuf[2];
		int outint;
		} u;
	
	u.outint = 0;
    //printf("\n\rRead digital compass\n\r");
	TWI_Start_Read(DIGITALCOMPASSTWIADDRESSRD,3);
    TWI_Get_Data_From_Transceiver(messageBuf,2);
	u.tempbuf[0] = messageBuf[0];
	u.tempbuf[1] = messageBuf[1];
	
    return u.outint;
}

// Write float value to LED8 via TWI
void Write_Float_SmartLCD(unsigned char twiaddress,unsigned char axisid,float fvalue)
{
 	 void *value;
	 
	 messageBuf[0] = 'm';
	 messageBuf[1] = axisid;
	 value = &messageBuf[2];
	 *(float *)value = fvalue;
	 TWI_Start_Write(twiaddress,messageBuf,6);
}

unsigned char Read_SmartLCD_Switches(char twiaddress)
{
	TWI_Start_Read(twiaddress,3);
    TWI_Get_Data_From_Transceiver(messageBuf,1);
    return messageBuf[0];
}

void Display_SmartLCD()
{
    float xpos,ypos,zpos,apos;
	
	//xpos = ((float)xoldpos)*xresolution;
	//if(xdirpolarity==NEGATIVE)  xpos = -xpos;
	Write_Float_SmartLCD(SMARTLCDTWIADDRESS,'x',xpos);
	Delaymsec(4);
	
	//ypos = ((float)yoldpos)*yresolution;
	//if(ydirpolarity==NEGATIVE)  ypos = -ypos;
	Write_Float_SmartLCD(SMARTLCDTWIADDRESS,'y',ypos);
	Delaymsec(4);

	//zpos = ((float)zoldpos)*zresolution;
	//if(zdirpolarity==NEGATIVE)  zpos = -zpos;
	Write_Float_SmartLCD(SMARTLCDTWIADDRESS,'z',zpos);
	Delaymsec(4);
					  
	//apos = ((float)holdpos)*aresolution;
	//if(adirpolarity==NEGATIVE)  apos = -apos;
	Write_Float_SmartLCD(SMARTLCDTWIADDRESS,'a',apos);
	//delaymsec(5);
}

void Enumerate_SmartLCD()
{
 	 smartlcdstate = 0;
	 
	 // Check for Smart Joystick
	 Init_SmartLCD_TWI(SMARTLCDTWIADDRESS);
     if(TWI_Get_State_Info()!=TWI_MTX_ADR_NACK) {
	 	 smartlcdstate |= 0x01;
	 	 Delaymsec(50);
	 	 Display_SmartLCD();
		 }
}

void Enumerate_DigitalCompass()
{
 	 digitalcompassstate = 0;
	 
	 // Send A command to digital compass to start a conversion
	 //printf("Init compass\n\r");
	 Init_DigitalCompass_TWI();
     if(TWI_Get_State_Info()!=TWI_MTX_ADR_NACK) {
	 	 digitalcompassstate |= 0x01;
	 	 Delaymsec(7);
		 }
}
const char enummes1[] = "\n\rEnumerate TWI Devices\n\r";
const char enummes8[] = " No SmartLCD found\n\r";
const char enummes9[] = " SmartLCD found - enabled\n\r";
const char enummes10[] = " No Digital Compass\n\r";
const char enummes11[] = " Digital Compass found\n\r";

void Enumerate_TWI_Devices()
{
 	 unsigned char i,motormask=0x01;
	
	 putfs(enummes1);	
	 
	 // Enumerate SmartLCD
	 Enumerate_SmartLCD();
	 if(smartlcdstate==0) putfs(enummes8);
	 else putfs(enummes9);
	 
	 // Enumerate Digital Compass
	 Enumerate_DigitalCompass();
	 if(digitalcompassstate==0) putfs(enummes10);
	 else putfs(enummes11);
}

const char TWImess1[] = "\n\rTWI Interactive Command Mode\n\r";
const char TWImess2[] = "Enter twi address (hex-two chars) followed by ASCII commands\n\r";
const char TWImess3[] = "  Example:  14xtx    Enter 'e' to exit\n\r";

// Send commands on I2C bus given twi address and an ASCII string
//  TBD - get data command
void Execute_TWI_Command()
{ 
     unsigned char twiaddress,iptr;
	  
	 putfs(TWImess1);
	 putfs(TWImess2);
	 putfs(TWImess3);
	 putchar(':');
 	 while((instrg[0]=tolower(getcharr()))!='e') {
	     instrg[1] = getcharr();
		 instrg[2] = 0;
		 sscanf(instrg,"%x",&twiaddress);
		 iptr = 0;
	     while((messageBuf[iptr++]=getcharr())!=CR) {
		     if(iptr==20) break;
			 }
		 messageBuf[iptr] = 0;
		 
		 printf("\n\rtwi=%x %s",twiaddress,messageBuf);
		 
		 TWI_Start_Write(twiaddress,messageBuf,iptr);

	     putCRLF(); putchar(':');
	     }
	 putCRLF();
}

