/**************************************************************

   Program Title:  Wasp AVR Monitor
   
   Program Name:  Wasp_Uart.c	Version: 0.85
   
   Author:  SS	  			    Date:  August 10, 2005
   
   Compiled with ImageCraft ICCAVR Standard V7.13A.
   
   This file contains routines that implement basic Usart put/get functions.
   
   Copyright 2004-2009, SOC Robotics, Inc.  All rights reserved.
   
****************************************************************/
/*
 * Copyright 2004-2009, SOC Robotics, Inc.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the copyright holders nor the names of
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 * 4. Redistribution is only allowed in combination with SOC Machines, 
 *    Inc. hardware products.
 *
 * THIS SOFTWARE IS PROVIDED BY SOC ROBOTICS, INC. AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL OC MACHINES, 
 * INC. OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * For additional information see http://www.soc-robotics.com
 */

/*
 * $Log: Wasp_Uart.c,v $
 * Revision 0.86  2006/02/07 16:40:20  SS
 *    2-wire interface, 8MHz clock, AVR Flash writer, XON/XOFF, 38,700baud
 * Revision 0.52  2005/06/04 18:36:42  SS
 * Preview release
 *
 */
#include <iom644v.h>
#include <macros.h>
#include <string.h>
#include <stdlib.h>
#include <stdio.h>
#include "Wasp_Uart.h"
#include "Wasp_Defines.h"
#include "Wasp_Extern.h"

int putchar(char indata)
{
	unsigned char tmphead;
	
	// Calculate buffer index
	tmphead = (UART_TxHead + 1) & UART_TX_BUFFER_MASK; 
		
	// Wait for free space in buffer
	while(tmphead == UART_TxTail) ;
	
	UART_TxBuf[tmphead] = indata; // store data in buffer
	UART_TxHead = tmphead;      // store new index

	// Expand LF to CRLF is textmode globel set
	if((indata==LF)&&(_textmode==1)) {
		// Calculate buffer index
		tmphead = (UART_TxHead + 1) & UART_TX_BUFFER_MASK; 
		
		// Wait for free space in buffer
		while(tmphead == UART_TxTail) ;
	
		UART_TxBuf[tmphead] = CR; // store data in buffer
		UART_TxHead = tmphead;      // store new index
		}

	UCSR0B |= (1<<UDRIE0);        // Fire TX UDRIE interrupt
	
	return 1;
}

void putcharr(unsigned char indata)
{
 	putchar(indata);
}

// Read and write functions
unsigned char getcharnw(void)
{
	unsigned char tmptail,rxtmp;

	if(UART_RxHead==UART_RxTail) return 0; // nothing to get
		
	tmptail = (UART_RxTail+1)&UART_RX_BUFFER_MASK;  // calculate buffer index
	UART_RxTail = tmptail;     // store new index
	
//	_CLI();
	rxcnt--;
	if(rxcnt<0) rxcnt = 0;
//	rxtmp = rxcnt;
//	_SEI();    // Enable interrupts => enable UART interrupts

//	if(rxtmp < 0) putcharr('<');
//	if(rxtmp > 0x3f) putcharr('>');

	// Allow tx at remote serial device again - buffer has more space
//	if((rxtmp<(UART_RX_BUFFER_SIZE-40))&&(xoffsent==YES)&&(enablexonoff==YES)) {
//		if(xonsent==NO) {
//			putcharr(XON);
// 			putcharr('$');
//			xonsent = YES;
//			}
//		}

	return UART_RxBuf[tmptail];   // return data
}

// Getchar waits until a valid character is received
unsigned char getchar(void)
{
    unsigned char inchar;
	
 	while(!(inchar=getcharnw())) ;
	if(echoinchars==YES) putcharr(inchar);
	return inchar;
}

// Getchar waits until a valid character is received
unsigned char getcharr(void)
{
    unsigned char inchar;
	
 	while(!(inchar=getcharnw())) ;
	if(echoinchars==YES) putcharr(inchar);
	return inchar;
}

/* Initialize UART */
void InittUART(unsigned char baudrate)
{
 	/* set the baud rate */
	UBRR0H = 0x00;
	UBRR0L = baudrate; 
	UCSR0B = BIT(RXEN0) | BIT(TXEN0); /* enable UART receiver and transmitter */
    //  8 data bits, 2 stop bits
//	UCSRC = (1<<URSEL)|(1<<USBS)|(3<<UCSZ0);
    //  8 data bits, 1 stop bit
	UCSR0C = (1<<UMSEL00)|(3<<UCSZ00);
}

// Polled receive function - non-wait
unsigned char ReceiveByte(void)
{
	if((UCSR0A & (1<<RXC0))) return UDR0;
	else return 0x00;
}

// Polled transmit function
void TransmitByte(unsigned char data)
{
	while ( !(UCSR0A & (1<<UDRE0)) )
		; /* wait for empty transmit buffer */
	UDR0 = data; /* start transmission */
}

//  Buffered write to UART - wait until transmitted
void puttchar(unsigned char data)
{
 	 TransmitByte(data);
}

//  Buffered character read from UART - don't return if 
//  character is Null
unsigned char gettchar(void)
{
     unsigned char inchar;
	 
 	 while(!(inchar=ReceiveByte())) ;
 	 return inchar;
}

/*
//  Convert binary value to ASCII int
void printint(int intvalue,char charcnt,char leadchartype)
{
 	 char outvalue[6],nolead;
 	 int  i,tenthousands, thousands, hundreds, tens;
	 
	 if(intvalue >= 0) putcharr(' ');
	 else {
	 	  putcharr('-');
	 	  intvalue *= -1;
		  }
	 tenthousands = intvalue/10000;
	 intvalue -= (tenthousands*10000);
	 thousands = intvalue/1000;
	 intvalue -= (thousands*1000);
	 hundreds = intvalue/100;
	 intvalue -= (hundreds*100);
	 tens = intvalue/10;
	 nolead = 0x00;
	 // TODO - suppress only leading zero's
	 if(tenthousands)  {outvalue[0] = '0' + tenthousands; nolead=0x01;}
	 else outvalue[0] = leadchartype;
	 if(thousands|nolead) {outvalue[1] = '0' + thousands;nolead=0x01;}
	 else outvalue[1] = leadchartype;
	 if(hundreds|nolead) {outvalue[2] = '0' + hundreds;nolead=0x01;}
	 else outvalue[2] = leadchartype;
	 if(tens|nolead) outvalue[3] = '0' + tens;
	 else outvalue[3] = leadchartype;
	 outvalue[4] = '0' + intvalue%10; 
	 outvalue[5] = 0x00;
	 for(i=0; i<charcnt; i++) putcharr(outvalue[(5-charcnt)+i]);
}
*/

int puts(char *outstrg)
{
 	 int i;
	 
	 for(i=0; i<strlen(outstrg); i++)  putchar(outstrg[i]);
	 
	 return 1;
}

void putss(char *outstrg)
{
 	 int i;
	 
	 for(i=0; i<strlen(outstrg); i++)  putcharr(outstrg[i]);
}

void putCRLF()
{
 	 puts("\n\r");
}


//  Load string constant from Flash (conserves RAM)
void putfs(const char *signon1)
{ 	
	char inchar;
    int i;
	
	i = 0;
	while((inchar=*(signon1+i++))!=0x00)  putcharr(inchar);
}

//  Convert byte to ASCII hex
void bytetohex(unsigned char byte)
{
    unsigned char inbyte,inchar;
	
	inbyte = byte & 0x0f;
	if(inbyte > 9) hexbyte[1] = (inbyte - 9) + 0x40;
	else hexbyte[1] = 0x30 + inbyte;
	inbyte = byte & 0xf0;
	inbyte >>= 4;
	if(inbyte >9) hexbyte[0] = (inbyte - 9) + 0x40;
	else hexbyte[0] = 0x30 + inbyte;
    hexbyte[2] = 0x00;
}

// Convert word to ASCII Hex
void addresstohex(unsigned int address)
{
 	 unsigned char lowbyte,highbyte;
	 
	 lowbyte = address & 0x00FF;
	 bytetohex(lowbyte);
	 hexaddress[2] = hexbyte[0];
	 hexaddress[3] = hexbyte[1];
	 highbyte = address/256;
	 bytetohex(highbyte);
	 hexaddress[0] = hexbyte[0];
	 hexaddress[1] = hexbyte[1];
	 hexaddress[4] = 0x00;
}

// Convert ASCII hex to binary
unsigned char converttohex(char *instrg)
{
 	 unsigned char lownibble, highnibble;
	 
	 if((instrg[0] >= 'A')&(instrg[0]<='F')) highnibble = instrg[0] - 'A' + 10;
	 else if((instrg[0] >= 'a')&(instrg[0]<='f')) highnibble = instrg[0] - 'a' + 10;
	 else highnibble = instrg[0] - '0';
	 
	 if((instrg[1] >= 'A')&(instrg[1]<='F')) lownibble = instrg[1] - 'A' + 10;
	 else if((instrg[1] >= 'a')&(instrg[1]<='f')) lownibble = instrg[1] - 'a' + 10;
	 else lownibble = instrg[1] - '0';
	 
	 highnibble = highnibble<<4;
	 return highnibble + lownibble;
}

